# Battlepy
Battlepy is a battle log generator.  Battlepy will create a player stats and enemy stats (PVP) and register the 
stats in a csv. We can train some IA algorithms and predict if the generated player can battle (without die) or avoid
the enemy. The player and enemies stats are created using same "mechanics" of the rpg games. 

This is for my initial researches in Data Science. This is in alpha stage and for academic learning only.

## Version 1.0-beta
- This initial release just works as intended. Run a predetermined quantity of battles and log in a csv.

## TODO for version 1.1
- Add a more complex mechanism, like block, critical, speed and etc.
- Add more weapons and armor items

